==> haskell-hasql-transaction-0.5.2-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5.2
id: hasql-transaction-0.5.2-HR6hLcqQsK1uLSu88UUmZ
key: hasql-transaction-0.5.2-HR6hLcqQsK1uLSu88UUmZ
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: cb9b4a0169dbb568430c85327235d522
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-transaction-0.5.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-transaction-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-transaction-0.5.2
hs-libraries: HShasql-transaction-0.5.2-HR6hLcqQsK1uLSu88UUmZ
depends:
    hasql-1.1.1-3G2QbnEHqno4DbU9DznHSj
    bytestring-tree-builder-0.2.7.1-Bza9erR0rJM8Oy9FbYdt5k
    bytestring-0.10.8.2 contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: hasql-1.1.1-3G2QbnEHqno4DbU9DznHSj=21e2ae79aa1be5dfa2a0c945c560e1dc
             bytestring-tree-builder-0.2.7.1-Bza9erR0rJM8Oy9FbYdt5k=4263331b58a1ca979f901b10e6e6f6c9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf=358ac830ec277a1de95ff9226a8ca243
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.5.2-45-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5.2
id: hasql-transaction-0.5.2-3MiSRfyyDMzF5u03TDmgYs
key: hasql-transaction-0.5.2-3MiSRfyyDMzF5u03TDmgYs
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 8f40c6d00858b3f1a39ad1dadcff2566
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-transaction-0.5.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-transaction-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hasql-transaction-0.5.2
hs-libraries: HShasql-transaction-0.5.2-3MiSRfyyDMzF5u03TDmgYs
depends:
    hasql-1.1.1-JSMQpfzZODk5QxczJmflyh
    bytestring-tree-builder-0.2.7.1-Bza9erR0rJM8Oy9FbYdt5k
    bytestring-0.10.8.2 contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: hasql-1.1.1-JSMQpfzZODk5QxczJmflyh=348478d5f05b4608caece2e66060b001
             bytestring-tree-builder-0.2.7.1-Bza9erR0rJM8Oy9FbYdt5k=4263331b58a1ca979f901b10e6e6f6c9
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             contravariant-extras-0.3.4-JUsruK2M2q178GgFofBYvf=358ac830ec277a1de95ff9226a8ca243
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=3e78347d5a15e89f4fb1084b18368182
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
